AnsiColors class

ANSI color codes for terminal output

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bgBlack(String text) String
Apply black background
bgBlue(String text) String
Apply blue background
bgCyan(String text) String
Apply cyan background
bgGreen(String text) String
Apply green background
bgMagenta(String text) String
Apply magenta background
bgRed(String text) String
Apply red background
bgWhite(String text) String
Apply white background
bgYellow(String text) String
Apply yellow background
black(String text) String
Apply black color
blue(String text) String
Apply blue color
bold(String text) String
Apply bold formatting
brightBlue(String text) String
Apply bright blue color
brightCyan(String text) String
Apply bright cyan color
brightGreen(String text) String
Apply bright green color
brightMagenta(String text) String
Apply bright magenta color
brightRed(String text) String
Apply bright red color
brightWhite(String text) String
Apply bright white color
brightYellow(String text) String
Apply bright yellow color
cyan(String text) String
Apply cyan color
dim(String text) String
Apply dim formatting
gray(String text) String
Apply gray color
green(String text) String
Apply green color
italic(String text) String
Apply italic formatting
magenta(String text) String
Apply magenta color
red(String text) String
Apply red color
reset(String text) String
Apply reset formatting
strip(String text) String
Strip ANSI codes from text
styled(String text, List<String> styles) String
Combine multiple styles
underline(String text) String
Apply underline formatting
white(String text) String
Apply white color
yellow(String text) String
Apply yellow color