ColorizedFormatter class

Colorized formatter using ANSI color codes

Inheritance

Constructors

ColorizedFormatter({bool enableColors = true, bool includeTimestamp = true, bool includeLevel = true, bool includeLoggerName = true, bool includeTag = true, String timestampFormat(DateTime)?})
const

Properties

enableColors bool
final
hashCode int
The hash code for this object.
no setterinherited
includeLevel bool
finalinherited
includeLoggerName bool
finalinherited
includeTag bool
finalinherited
includeTimestamp bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampFormat String Function(DateTime)?
finalinherited

Methods

format(LogEntry entry) String
Format a log entry into a string
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited