ConsoleSink class

Console sink that outputs to stdout/stderr

Inheritance

Constructors

ConsoleSink({LogFormatter? formatter, LogLevel? errorThreshold})

Properties

hashCode int
The hash code for this object.
no setterinherited
isAvailable bool
Check if this sink is available on the current platform
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all logs in this sink (if supported)
inherited
dispose() Future<void>
Dispose any resources used by this sink
inherited
log(LogEntry entry) Future<void>
Log an entry to this sink
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited