JsonFormatter class

JSON formatter for structured logging

Inheritance

Constructors

JsonFormatter({bool prettyPrint = false, bool includeContext = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
includeContext bool
final
prettyPrint bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

format(LogEntry entry) String
Format a log entry into a string
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited