LogLevel enum

Represents the severity level of a log entry

Inheritance
Available extensions

Values

trace → const LogLevel
const LogLevel(0, 'TRACE')
debug → const LogLevel
const LogLevel(10, 'DEBUG')
info → const LogLevel
const LogLevel(20, 'INFO')
warn → const LogLevel
const LogLevel(30, 'WARN')
error → const LogLevel
const LogLevel(40, 'ERROR')
fatal → const LogLevel
const LogLevel(50, 'FATAL')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
String representation of the log level
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
priority int
Numeric priority for comparison (lower = less severe)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isEnabled(LogLevel minimumLevel) bool
Check if this level is enabled for a minimum level
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String level) LogLevel?
Parse log level from string (case insensitive)

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.