shouldRotateDaily static method
Check if a file should be rotated based on date
Implementation
static bool shouldRotateDaily(DateTime fileDate, [DateTime? now]) {
final current = now ?? DateTime.now();
return !isSameDay(fileDate, current);
}
Check if a file should be rotated based on date
static bool shouldRotateDaily(DateTime fileDate, [DateTime? now]) {
final current = now ?? DateTime.now();
return !isSameDay(fileDate, current);
}