isAvailable property
bool
get
isAvailable
Check if this sink is available on the current platform
Implementation
bool get isAvailable => true;
Check if this sink is available on the current platform
bool get isAvailable => true;