PlatformUtils class

Utility class for platform detection and capabilities

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isCI bool
Check if running in a CI environment
no setter
isDevelopment bool
Check if running in development mode
no setter
isProfile bool
Check if running in profile mode
no setter
isRelease bool
Check if running in release mode
no setter
platformName String
Get the platform name
no setter
supportsAnsiColors bool
Check if the current platform supports ANSI colors
no setter
supportsFileIO bool
Check if file I/O is supported on this platform
no setter
supportsHttp bool
Check if HTTP requests are supported
no setter