PrintX class

Main PrintX class providing a simple, print-like API

Constructors

PrintX(String message)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

api PrintXSpecializedLogger
API-specific logging
no setter
auth PrintXSpecializedLogger
Authentication-specific logging
no setter
db PrintXSpecializedLogger
Database-specific logging
no setter
network PrintXSpecializedLogger
Network-specific logging
no setter
ui PrintXSpecializedLogger
UI-specific logging
no setter

Static Methods

call(Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Print a trace message (equivalent to print)
clearLogs() Future<void>
Clear all logs
debug(Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Debug level logging
debugLazy(String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Debug with lazy evaluation
dispose() Future<void>
Dispose all resources
error(Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Error level logging
errorLazy(String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Error with lazy evaluation
exportLogs() Future<String?>
Export logs for debugging
fatal(Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Fatal level logging
fatalLazy(String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Fatal with lazy evaluation
getLogger(String name) LoggerBase
Get a custom logger by name
info(Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Info level logging (default print replacement)
infoLazy(String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Info with lazy evaluation
initialize({LogLevel? minimumLevel, bool enableConsoleLogging = true, bool enableFileLogging = false, bool enableDeveloperLogging = true, bool enableColorOutput = true, String? logDirectory, bool captureFlutterErrors = true}) Future<void>
Initialize PrintX with default configuration
isEnabled(LogLevel level) bool
Check if a log level is enabled
setColorOutput(bool enableColorOutput) → void
Enable or disable color output globally
setMinimumLevel(LogLevel level) → void
Set global minimum log level
trace(Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Trace level logging
traceLazy(String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Trace with lazy evaluation
warn(Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Warning level logging
warnLazy(String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map<String, dynamic>? context}) → void
Warning with lazy evaluation