SimpleFormatter class

Simple text formatter without colors

Inheritance
Implementers

Constructors

SimpleFormatter({bool includeTimestamp = true, bool includeLevel = true, bool includeLoggerName = true, bool includeTag = true, String timestampFormat(DateTime)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
includeLevel bool
final
includeLoggerName bool
final
includeTag bool
final
includeTimestamp bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampFormat String Function(DateTime)?
final

Methods

format(LogEntry entry) String
Format a log entry into a string
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited