LevelFilter class
Filter that only allows log entries at or above a minimum level
Constructors
- LevelFilter(LogLevel minimumLevel)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minimumLevel → LogLevel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldLog(
LogEntry entry) → bool -
Determine if a log entry should be logged
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited