PrintXSpecializedLogger class
Specialized logger wrapper for pre-configured loggers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → LoggerBase
-
Access the underlying logger
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Debug level logging
-
debugLazy(
String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Debug with lazy evaluation
-
error(
Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Error level logging
-
errorLazy(
String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Error with lazy evaluation
-
fatal(
Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Fatal level logging
-
fatalLazy(
String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Fatal with lazy evaluation
-
info(
Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Info level logging
-
infoLazy(
String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Info with lazy evaluation
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trace(
Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Trace level logging
-
traceLazy(
String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Trace with lazy evaluation
-
warn(
Object? message, {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Warning level logging
-
warnLazy(
String messageBuilder(), {String? tag, Object? error, StackTrace? stackTrace, Map< String, dynamic> ? context}) → void - Warning with lazy evaluation
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited